<p align="center">
  <a href="https://chromatinhd.eu">
    <img src="https://raw.githubusercontent.com/DeplanckeLab/ChromatinHD/main/docs/source/static/logo.png" width="300" />
  </a>
</p>

For a full quickstart, see <https://chromatinhd.eu/quickstart/0_install>
